@@ -175,79 +175,6 @@ export_table <- function(df) {
                 ))
 }
 
-
-
-
-#' Summary function for labelled vector
-#'
-#'
-#' @param object a labelled vector
-#' @param ... passed to summary.factor
-#'
-#' @export
-#' @examples
-#' example("labelled", "haven")
-#' summary(x)
-#'
-summary.labelled <- function(object, ...) {
-  summary(haven::as_factor(object, levels = "both"), ...)
-}
-
-#' Summary function for labelled_spss vector
-#'
-#'
-#' @param object a labelled_spss vector
-#' @param ... passed to summary.factor
-#'
-#' @export
-#' @examples
-#' example("labelled", "haven")
-#' summary(x)
-#'
-summary.labelled_spss <- function(object, ...) {
-  summary(haven::as_factor(object, levels = "both"), ...)
-}
-
-
-
-#' Has label
-#'
-#'
-#' @param x a vector
-#'
-#' @export
-#' @examples
-#' example("labelled", "haven")
-#' has_label(x)
-has_label <- function(x) {
-  haven::is.labelled(x) ||
-    !is.null(attr(x, 'label')) ||
-    !is.null(attr(x, 'labels'))
-}
-
-
-#' Has labels
-#'
-#'
-#' @param x a vector
-#'
-#' @export
-#' @examples
-#' example("labelled", "haven")
-#' has_labels(x)
-has_labels <- function(x) {
-  haven::is.labelled(x) ||
-    !is.null(attr(x, 'labels'))
-}
-
-#' @export
-as_factor.default <- function(x,
-          levels = c("default", "labels", "values", "both"),
-          ordered = FALSE, ...) {
-  class(x) <- c("haven_labelled", class(x))
-  haven::as_factor(x, levels, ordered, ...)
-}
-
 is_attribute_set <- function(attribute, data) {
   !is.null(attr(data, attribute, exact = TRUE))
 }
