@@ -1,43 +1,43 @@
-## ----message = FALSE-----------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 knit_by_pkgdown <- !is.null(knitr::opts_chunk$get("fig.retina"))
-knitr::opts_chunk$set(warning = FALSE, message = FALSE, error = TRUE, echo = TRUE)
+knitr::opts_chunk$set(warning = FALSE, message = FALSE, error = FALSE, echo = TRUE)
 pander::panderOptions("table.split.table", Inf)
 ggplot2::theme_set(ggplot2::theme_bw())
 library(codebook)
 library(dplyr)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # library(qualtRics) # currently not on CRAN, so commented out
 results <- readRDS(system.file("extdata", "ryan.rds", package = "codebook"))
 metadata_ex <- readRDS(system.file("extdata", "metadata.rds", package = "codebook"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 results <- results %>% rio::gather_attrs()
 attributes(results)$label$Q7
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 names(metadata_ex$questions) <- lapply(metadata_ex$questions, function(x) {
   x$questionName
 })
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 qs <- names(metadata_ex$questions)
 qs <- qs[qs %in% names(attributes(results)$label)]
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 init <- vector("list", ncol(results)) 
 names(init) <- names(results)
 attributes(results)$item <- init
 attributes(results)$item[qs] <- metadata_ex$questions[qs]
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 results <- results %>% rio::spread_attrs()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 results <- results %>% select(ResponseSet, Q7, Q10)
 if (!knit_by_pkgdown) knitr::opts_chunk$set(echo = FALSE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 metadata(results)$name <- "MOCK Qualtrics dataset"
 metadata(results)$description <- "a MOCK dataset used to show how to import Qualtrics metadata into the codebook R package"
 metadata(results)$identifier <- "doi:10.5281/zenodo.1326520"
@@ -52,11 +52,11 @@ metadata(results)$url <- "https://rubenarslan.github.io/codebook/articles/codebo
 metadata(results)$temporalCoverage <- "2018" 
 metadata(results)$spatialCoverage <- "Nowhere" 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # We don't want to look at the code in the codebook.
 knitr::opts_chunk$set(warning = TRUE, message = TRUE, echo = FALSE)
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (exists("testing")) {
 	indent = '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
 	results = data("bfi")
@@ -67,45 +67,45 @@ meta <- metadata(results)
 description <- meta$description
 meta <- recursive_escape(meta)
 
-## ----results='asis'------------------------------------------------------
+## ----results='asis'-----------------------------------------------------------
 if (exists("name", meta)) {
   glue::glue(
     "__Dataset name__: {name}",
     .envir = meta)
 }
 
-## ----results='asis'------------------------------------------------------
+## ----results='asis'-----------------------------------------------------------
 cat(description)
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("temporalCoverage", meta)) {
   glue::glue(
     "- __Temporal Coverage__: {temporalCoverage}",
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("spatialCoverage", meta)) {
   glue::glue(
     "- __Spatial Coverage__: {spatialCoverage}",
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("citation", meta)) {
   glue::glue(
     "- __Citation__: {citation}",
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("url", meta)) {
   glue::glue(
     "- __URL__: [{url}]({url})",
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("identifier", meta)) {
   if (stringr::str_detect(meta$identifier, "^doi:")) {
     meta$identifier <- paste0('<a href="https://dx.doi.org/', 
@@ -117,27 +117,27 @@ if (exists("identifier", meta)) {
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("datePublished", meta)) {
   glue::glue(
     "- __Date published__: {datePublished}",
     .envir = meta)
 }
 
-## ----results='asis', echo = FALSE----------------------------------------
+## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("creator", meta)) {
   cat("- __Creator__:")
   pander::pander(meta$creator)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 meta <- meta[setdiff(names(meta),
                      c("creator", "datePublished", "identifier",
                        "url", "citation", "spatialCoverage", 
                        "temporalCoverage", "description", "name"))]
 pander::pander(meta)
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
@@ -155,7 +155,7 @@ item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label),
 item_info <- item_attributes$item
 choices <- item_attributes$labels
 
-## ----setup_missing_values------------------------------------------------
+## ----setup_missing_values-----------------------------------------------------
 show_missing_values <- FALSE
 if (has_labels(item)) {
   missing_values <- item[is.na(haven::zap_missing(item))]
@@ -213,7 +213,7 @@ if ( go_vertical ) {
 
 wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 
-## ----distribution--------------------------------------------------------
+## ----distribution-------------------------------------------------------------
 # todo: if there are free-text choices mingled in with the pre-defined ones, don't show
 # todo: show rare items if they are pre-defined
 # todo: bin rare responses into "other category"
@@ -233,18 +233,18 @@ if (!length(item_nomiss)) {
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
-## ----summary-------------------------------------------------------------
+## ----summary------------------------------------------------------------------
 attributes(item) <- item_attributes
 df = data.frame(item, stringsAsFactors = FALSE)
 names(df) = html_item_name
 escaped_table(codebook_table(df))
 
-## ----missing_values------------------------------------------------------
+## ----missing_values-----------------------------------------------------------
 if (show_missing_values) {
   plot_labelled(missing_values, item_name, wrap_at)
 }
 
-## ----item_info-----------------------------------------------------------
+## ----item_info----------------------------------------------------------------
 if (!is.null(item_info)) {
   # don't show choices again, if they're basically same thing as value labels
   if (!is.null(choices) && !is.null(item_info$choices) && 
@@ -257,12 +257,12 @@ if (!is.null(item_info)) {
   pander::pander(item_info)
 }
 
-## ----choices-------------------------------------------------------------
+## ----choices------------------------------------------------------------------
 if (!is.null(choices) && length(choices) && length(choices) < 30) {
 	pander::pander(as.list(choices))
 }
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
@@ -280,7 +280,7 @@ item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label),
 item_info <- item_attributes$item
 choices <- item_attributes$labels
 
-## ----setup_missing_values------------------------------------------------
+## ----setup_missing_values-----------------------------------------------------
 show_missing_values <- FALSE
 if (has_labels(item)) {
   missing_values <- item[is.na(haven::zap_missing(item))]
@@ -338,7 +338,7 @@ if ( go_vertical ) {
 
 wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 
-## ----distribution--------------------------------------------------------
+## ----distribution-------------------------------------------------------------
 # todo: if there are free-text choices mingled in with the pre-defined ones, don't show
 # todo: show rare items if they are pre-defined
 # todo: bin rare responses into "other category"
@@ -358,18 +358,18 @@ if (!length(item_nomiss)) {
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
-## ----summary-------------------------------------------------------------
+## ----summary------------------------------------------------------------------
 attributes(item) <- item_attributes
 df = data.frame(item, stringsAsFactors = FALSE)
 names(df) = html_item_name
 escaped_table(codebook_table(df))
 
-## ----missing_values------------------------------------------------------
+## ----missing_values-----------------------------------------------------------
 if (show_missing_values) {
   plot_labelled(missing_values, item_name, wrap_at)
 }
 
-## ----item_info-----------------------------------------------------------
+## ----item_info----------------------------------------------------------------
 if (!is.null(item_info)) {
   # don't show choices again, if they're basically same thing as value labels
   if (!is.null(choices) && !is.null(item_info$choices) && 
@@ -382,12 +382,12 @@ if (!is.null(item_info)) {
   pander::pander(item_info)
 }
 
-## ----choices-------------------------------------------------------------
+## ----choices------------------------------------------------------------------
 if (!is.null(choices) && length(choices) && length(choices) < 30) {
 	pander::pander(as.list(choices))
 }
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
@@ -405,7 +405,7 @@ item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label),
 item_info <- item_attributes$item
 choices <- item_attributes$labels
 
-## ----setup_missing_values------------------------------------------------
+## ----setup_missing_values-----------------------------------------------------
 show_missing_values <- FALSE
 if (has_labels(item)) {
   missing_values <- item[is.na(haven::zap_missing(item))]
@@ -463,7 +463,7 @@ if ( go_vertical ) {
 
 wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 
-## ----distribution--------------------------------------------------------
+## ----distribution-------------------------------------------------------------
 # todo: if there are free-text choices mingled in with the pre-defined ones, don't show
 # todo: show rare items if they are pre-defined
 # todo: bin rare responses into "other category"
@@ -483,18 +483,18 @@ if (!length(item_nomiss)) {
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
-## ----summary-------------------------------------------------------------
+## ----summary------------------------------------------------------------------
 attributes(item) <- item_attributes
 df = data.frame(item, stringsAsFactors = FALSE)
 names(df) = html_item_name
 escaped_table(codebook_table(df))
 
-## ----missing_values------------------------------------------------------
+## ----missing_values-----------------------------------------------------------
 if (show_missing_values) {
   plot_labelled(missing_values, item_name, wrap_at)
 }
 
-## ----item_info-----------------------------------------------------------
+## ----item_info----------------------------------------------------------------
 if (!is.null(item_info)) {
   # don't show choices again, if they're basically same thing as value labels
   if (!is.null(choices) && !is.null(item_info$choices) && 
@@ -507,12 +507,12 @@ if (!is.null(item_info)) {
   pander::pander(item_info)
 }
 
-## ----choices-------------------------------------------------------------
+## ----choices------------------------------------------------------------------
 if (!is.null(choices) && length(choices) && length(choices) < 30) {
 	pander::pander(as.list(choices))
 }
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack
 }
@@ -523,7 +523,7 @@ if (exists("testing")) {
 	md_pattern <- data.frame()
 }
 
-## ----missingness_all_setup-----------------------------------------------
+## ----missingness_all_setup----------------------------------------------------
 if (length(md_pattern)) {
   if (knitr::is_html_output()) {
     rmarkdown::paged_table(md_pattern, options = list(rows.print = 10))
@@ -532,7 +532,7 @@ if (length(md_pattern)) {
   }
 }
 
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
+## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
 	indent <- '#' # ugly hack
 }
@@ -548,31 +548,31 @@ if (exists("testing")) {
 	detailed_scales <- TRUE
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 knitr::asis_output(data_info)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 knitr::asis_output(survey_overview)
 
-## ----scales--------------------------------------------------------------
+## ----scales-------------------------------------------------------------------
 if (detailed_variables || detailed_scales) {
   knitr::asis_output(paste0(scales_items, sep = "\n\n\n", collapse = "\n\n\n"))
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 missingness_report
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 items
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 jsonld
 
-## ----cb------------------------------------------------------------------
+## ----cb-----------------------------------------------------------------------
 codebook(results, survey_repetition = "single",
          metadata_table = knit_by_pkgdown, metadata_json = knit_by_pkgdown)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 if (!knit_by_pkgdown) {
   codebook:::escaped_table(codebook_table(results))
 }
